searchData={"items":[{"type":"module","title":"HtmlQuery","doc":"A concise HTML query API. HTML parsing is handled by [Floki](https://hex.pm/packages/floki).\n\nWe created a related library called [XmlQuery](https://hexdocs.pm/xml_query/readme.html) which has the same API but\nis used for querying XML. You can read more about them in\n[Querying HTML and XML in Elixir with HtmlQuery and XmlQuery](https://eahanson.com/articles/html-query-xml-query).","ref":"HtmlQuery.html"},{"type":"module","title":"Data types - HtmlQuery","doc":"All functions can accept HTML in the form of a string, a Floki HTML tree, a Floki HTML node, or anything that\nimplements the `String.Chars` protocol. See `t:HtmlQuery.html/0`.\n\nSome functions take a CSS selector, which can be a string, a keyword list, or a list.\nSee `t:HtmlQuery.Css.selector/0`.","ref":"HtmlQuery.html#module-data-types"},{"type":"module","title":"Query functions - HtmlQuery","doc":"| `all/2`   | return all elements matching the selector                   |\n| `find/2`  | return the first element that matches the selector          |\n| `find!/2` | return the only element that matches the selector, or raise |","ref":"HtmlQuery.html#module-query-functions"},{"type":"module","title":"Extraction functions - HtmlQuery","doc":"| `attr/2`        | returns the attribute value as a string                 |\n| `form_fields/1` | returns the names and values of form fields as a map    |\n| `meta_tags/1`   | returns the names and values of metadata fields         |\n| `table/2`       | returns the cells of a table as a list of lists or maps |\n| `text/2`        | returns the text contents as a single string            |","ref":"HtmlQuery.html#module-extraction-functions"},{"type":"module","title":"Parsing functions - HtmlQuery","doc":"| `parse/1`     | parses an HTML fragment into a [Floki HTML tree] |\n| `parse_doc/1` | parses an HTML doc into a [Floki HTML tree]      |","ref":"HtmlQuery.html#module-parsing-functions"},{"type":"module","title":"Utility functions - HtmlQuery","doc":"| `inspect_html/2` | prints prettified HTML with a label   |\n| `normalize/1`    | parses and re-stringifies HTML        |\n| `pretty/1`       | prettifies HTML                       |\n| `reject/2`       | removes nodes that match the selector |","ref":"HtmlQuery.html#module-utility-functions"},{"type":"module","title":"Alias - HtmlQuery","doc":"If you use HtmlQuery a lot, you may want to alias it to the recommended shortcut \"Hq\":\n\n```elixir\nalias HtmlQuery, as: Hq\n```","ref":"HtmlQuery.html#module-alias"},{"type":"module","title":"Examples - HtmlQuery","doc":"Get the value of a selected option:\n\n```elixir\niex> html = ~s|   apples   bananas   |\niex> HtmlQuery.find(html, \"select option[selected]\") |> HtmlQuery.attr(\"value\")\n\"a\"\n```\n\nGet the text of a selected option, raising if there are more than one:\n\n```elixir\niex> html = ~s|   apples   bananas   |\niex> HtmlQuery.find!(html, \"select option[selected]\") |> HtmlQuery.text()\n\"apples\"\n```\n\nGet the text of all the options:\n\n```elixir\niex> html = ~s|   apples   bananas   |\niex> HtmlQuery.all(html, \"select option\") |> Enum.map(&HtmlQuery.text/1)\n[\"apples\", \"bananas\"]\n```\n\nUse a keyword list as the selector (see `HtmlQuery.Css` for details on selectors):\n\n```elixir\niex> html = ~s|   logout   |\niex> HtmlQuery.find!(html, test_role: \"logout-link\") |> HtmlQuery.attr(\"href\")\n\"/logout\"\n```","ref":"HtmlQuery.html#module-examples"},{"type":"function","title":"HtmlQuery.all/2","doc":"Finds all elements in `html` that match `selector`, returning a Floki HTML tree.\n\n```elixir\niex> html = ~s|   apples   bananas   |\niex> HtmlQuery.all(html, \"option\")\n[\n  {\"option\", [{\"value\", \"a\"}, {\"selected\", \"selected\"}], [\"apples\"]},\n  {\"option\", [{\"value\", \"b\"}], [\"bananas\"]}\n]\n```","ref":"HtmlQuery.html#all/2"},{"type":"type","title":"HtmlQuery.attr/0","doc":"A string or atom representing an attribute name. If an atom, underscores are converted to dashes.","ref":"HtmlQuery.html#t:attr/0"},{"type":"function","title":"HtmlQuery.attr/2","doc":"Returns the value of `attr` from the outermost element of `html`.\nIf `attr` is an atom, any underscores are converted to dashes.\n\n```elixir\niex> html = ~s|   logout   |\niex> HtmlQuery.find!(html, test_role: \"logout-link\") |> HtmlQuery.attr(\"href\")\n\"/logout\"\n```","ref":"HtmlQuery.html#attr/2"},{"type":"function","title":"HtmlQuery.find/2","doc":"Finds the first element in `html` that matches `selector`, returning a Floki HTML node.\n\n```elixir\niex> html = ~s|   apples   bananas   |\niex> HtmlQuery.find(html, \"select option[selected]\")\n{\"option\", [{\"value\", \"a\"}, {\"selected\", \"selected\"}], [\"apples\"]}\n```","ref":"HtmlQuery.html#find/2"},{"type":"function","title":"HtmlQuery.find!/2","doc":"Like `find/2` but raises unless exactly one element is found.","ref":"HtmlQuery.html#find!/2"},{"type":"function","title":"HtmlQuery.form_fields/1","doc":"Returns a map containing the form fields of form `selector` in `html`. Because it returns a map, any information\nabout the order of form fields is lost.\n\n```elixir\niex> html = ~s|     A tree   |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{color: \"green\", desc: \"A tree\"}\n```\n\nField names are converted to snake case atoms:\n\n```elixir\niex> html = ~s|     |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{favorite_color: \"green\"}\n```\n\nIf form field names are in `foo[bar]` format, then `foo` becomes a key to a nested map containing `bar`:\n\n```elixir\niex> html = ~s|       |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{profile: %{name: \"fido\", age: \"10\"}}\n```\n\nIf a text field has no value attribute, it will not be returned at all:\n\n```elixir\niex> html = ~s|     |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{}\n\niex> html = ~s|     |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{empty_value: \"\"}\n\niex> html = ~s|     |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{non_empty_value: \"something\"}\n```\n\nThe checked value of a radio button set is returned, or `nil` is returned if no value is checked:\n\n```elixir\niex> html = ~s|       |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{x: \"2\"}\n\niex> html = ~s|       |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{x: nil}\n```\n\nWhen evaluating checkboxes, the `name` attribute of the input defines whether or not a term or a\nlist will be returned. A name that ends in `[]` allows a browser to send multiple values, in which case\nour form fields will return an array of values. A name that does not end in `[]` will evaluate to a\nsingle value, the last checked value in a list:\n\n```elixir\niex> html = ~s|       |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{x: \"2\"}\n\niex> html = ~s|       |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{x: nil}\n\niex> html = ~s| \n...>    \n...>    \n...>    \n...>    \n...>  |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{x: false, y: true}\n\niex> html = ~s|       |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{x: [\"1\", \"2\"]}\n\niex> html = ~s|       |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{x: []}\n```","ref":"HtmlQuery.html#form_fields/1"},{"type":"type","title":"HtmlQuery.html/0","doc":"A string, a struct that implements the `String.Chars` protocol,\na [Floki HTML tree], or a [Floki HTML node].\n\n[Floki HTML tree]: https://hexdocs.pm/floki/Floki.html#t:html_tree/0\n[Floki HTML node]: https://hexdocs.pm/floki/Floki.html#t:html_node/0","ref":"HtmlQuery.html#t:html/0"},{"type":"function","title":"HtmlQuery.inspect_html/2","doc":"Prints prettified `html` with a label, and then returns the original html.","ref":"HtmlQuery.html#inspect_html/2"},{"type":"function","title":"HtmlQuery.meta_tags/1","doc":"Extracts all the meta tags from `html`, returning a list of maps.\n\n```elixir\niex> html = ~s|       |\niex> HtmlQuery.meta_tags(html)\n[%{\"charset\" => \"utf-8\"}, %{\"content\" => \"IE=edge\", \"http-equiv\" => \"X-UA-Compatible\"}]\n```","ref":"HtmlQuery.html#meta_tags/1"},{"type":"function","title":"HtmlQuery.normalize/1","doc":"Parses and then re-stringifies `html`, increasing the liklihood that two equivalent HTML strings can\nbe considered equal.\n\n```elixir\niex> a = ~s| green |\niex> b = ~s| green |\niex> a == b\nfalse\niex> HtmlQuery.normalize(a) == HtmlQuery.normalize(b)\ntrue\n```","ref":"HtmlQuery.html#normalize/1"},{"type":"function","title":"HtmlQuery.parse/1","doc":"Parses an HTML fragment using `Floki.parse_fragment!/1`, returning a Floki HTML tree.","ref":"HtmlQuery.html#parse/1"},{"type":"function","title":"HtmlQuery.parse_doc/1","doc":"Parses an HTML document using `Floki.parse_document!/1`, returning a Floki HTML tree.","ref":"HtmlQuery.html#parse_doc/1"},{"type":"function","title":"HtmlQuery.pretty/1","doc":"Returns `html` as a prettified string (delgates to `Floki.raw_html/2` with the `pretty: true` option).","ref":"HtmlQuery.html#pretty/1"},{"type":"function","title":"HtmlQuery.reject/2","doc":"Returns `html` after removing all nodes that don't match `selector` (delegates to `Floki.filter_out/2`).\n\n```elixir\niex> html = ~s|   Alice   topaz   |\niex> HtmlQuery.reject(html, id: \"password\") |> HtmlQuery.normalize()\n~s|  Alice  |\n```","ref":"HtmlQuery.html#reject/2"},{"type":"function","title":"HtmlQuery.table/2","doc":"Returns the contents of the table as a list of lists.\n\nOptions:\n* `as` - if `:lists` (the default), returns the table as a list of lists; if `:maps`, returns the table as a list of\n  maps.\n* `only` - a list of the indices of the columns to return; a list of column headers (as strings) to return,\n  assuming that the first row of the table is the columns names; or `:all` to return all columns (which is the same\n  as not specifying this option at all).\n* `except` - returns all the columns except the ones whose indices or names are given. `only` and `except` can be\n  combined to further reduce the set of columns.\n* `headers` - if `true` (the default), returns the list of headers along with the rows. Ignored if `as` option is\n  `:maps`.\n\nDeprecated options:\n* `columns` - use `only` instead.\n\n```elixir\niex> html = \"    A  B  C     1  2  3    \"\niex> HtmlQuery.table(html)\n[\n  [\"A\", \"B\", \"C\"],\n  [\"1\", \"2\", \"3\"]\n]\niex> HtmlQuery.table(html, as: :maps)\n[\n  %{\"A\" => \"1\", \"B\" => \"2\", \"C\" => \"3\"}\n]\niex> HtmlQuery.table(html, only: [0, 2])\n[\n  [\"A\", \"C\"],\n  [\"1\", \"3\"]\n]\niex> HtmlQuery.table(html, only: [2, 0])\n[\n  [\"C\", \"A\"],\n  [\"3\", \"1\"]\n]\niex> HtmlQuery.table(html, only: [\"C\", \"A\"])\n[\n  [\"C\", \"A\"],\n  [\"3\", \"1\"]\n]\niex> HtmlQuery.table(html, except: [\"C\", \"A\"])\n[\n  [\"B\"],\n  [\"2\"]\n]\niex> HtmlQuery.table(html, only: [\"C\", \"A\"], headers: false)\n[\n  [\"3\", \"1\"]\n]\n```","ref":"HtmlQuery.html#table/2"},{"type":"function","title":"HtmlQuery.text/2","doc":"Returns the text value of `html`, separating substrings with a space by default. (Floki will split text into\nsubstrings.) You can pass a separator as the second argument; sometimes it's useful to pass an empty string.\n\n```elixir\niex> html = ~s|   apples   bananas   |\niex> HtmlQuery.find!(html, \"select option[selected]\") |> HtmlQuery.text()\n\"apples\"\n```","ref":"HtmlQuery.html#text/2"},{"type":"module","title":"HtmlQuery.Css","doc":"Constructs CSS selectors via Elixir data structures. See `selector/1` for details.","ref":"HtmlQuery.Css.html"},{"type":"type","title":"HtmlQuery.Css.selector/0","doc":"See docs for `selector/1` for more details.","ref":"HtmlQuery.Css.html#t:selector/0"},{"type":"function","title":"HtmlQuery.Css.selector/1","doc":"Accepts a string, atom, keyword list, or list, and returns a CSS string.","ref":"HtmlQuery.Css.html#selector/1"},{"type":"function","title":"String syntax - HtmlQuery.Css.selector/1","doc":"When given a string, returns the string. This is useful when you don't know if a selector is already a string.\n\n```elixir\niex> HtmlQuery.Css.selector(\".profile[test-role='new-members']\")\n\".profile[test-role='new-members']\"\n```","ref":"HtmlQuery.Css.html#selector/1-string-syntax"},{"type":"function","title":"Atom syntax - HtmlQuery.Css.selector/1","doc":"When given an atom, converts the atom to a string, without converting underscores to dashes.\n\n```elixir\niex> HtmlQuery.Css.selector(:p)\n\"p\"\n```","ref":"HtmlQuery.Css.html#selector/1-atom-syntax"},{"type":"function","title":"Keyword list syntax - HtmlQuery.Css.selector/1","doc":"_The keyword list syntax is intentionally limited; complex selectors are more\neasily written as strings._\n\nThe keyword list syntax makes it a bit eaiser to write simple selectors or selectors that use variables:\ne.g.:\n\n```elixir\nHtmlQuery.Css.selector(test_role: \"new-members\")\nHtmlQuery.Css.selector(id: some_variable)\n```\n\nKeys are expected to be atoms and will be dasherized (`foo_bar` -> `foo-bar`).\nValues are expected to be strings or another keyword list.\n\nA key/value pair will be converted to an attribute selector:\n```elixir\niex> HtmlQuery.Css.selector(test_role: \"new-members\")\n\"[test-role='new-members']\"\n```\n\nA keyword list will be converted to a list of attribute selectors:\n\n```elixir\niex> HtmlQuery.Css.selector(class: \"profile\", test_role: \"new-members\")\n\"[class='profile'][test-role='new-members']\"\n```\n\n(Note that the CSS selector `.profile` expands to `[class~='profile']` which is not equivalent to\n`[class='profile']`. The keyword list syntax will not generate `~=` selectors so you should use a\nstring selector such as `\".profile[test-role='new-members']\"` instead if you want `~=` semantics. See the\n[CSS spec](https://www.w3.org/TR/CSS21/selector.html#attribute-selectors) for details.)\n\nWhen the value is a keyword list, the key is converted to an element selector:\n\n```elixir\niex> HtmlQuery.Css.selector(p: [class: \"profile\", test_role: \"new-members\"])\n\"p[class='profile'][test-role='new-members']\"\n```","ref":"HtmlQuery.Css.html#selector/1-keyword-list-syntax"},{"type":"function","title":"List syntax - HtmlQuery.Css.selector/1","doc":"_The list syntax is intentionally limited; complex selectors are more\neasily written as strings._\n\nWhen the value is a list (vs a keyword list), atoms are converted to element selectors and\nkeyword lists are converted as described above.\n\n```elixir\niex> HtmlQuery.Css.selector([[p: [class: \"profile\", test_role: \"new-members\"]], :div, [class: \"tag\"]])\n\"p[class='profile'][test-role='new-members'] div [class='tag']\"\n```","ref":"HtmlQuery.Css.html#selector/1-list-syntax"},{"type":"module","title":"HtmlQuery.Form","doc":"Form-handling functions. Most of the time, `HtmlQuery.form_fields/1` should be used instead of calling these\nfunctions directly.","ref":"HtmlQuery.Form.html"},{"type":"function","title":"HtmlQuery.Form.fields/1","doc":"","ref":"HtmlQuery.Form.html#fields/1"},{"type":"exception","title":"HtmlQuery.QueryError","doc":"An exception raised when unable to find an HTML element.","ref":"HtmlQuery.QueryError.html"},{"type":"extras","title":"HtmlQuery","doc":"# HtmlQuery\n\nA concise API, honed over multiple years, for querying HTML. There are just 5 main functions:\n`all/2`, `find/2` and `find!/2` for finding things, plus `attr/2` and `text/1` for extracting\ninformation. There are also a handful of other useful functions, referenced below and described in detail in\nthe [module docs](https://hexdocs.pm/html_query/HtmlQuery.html). HTML parsing is handled by\n[Floki](https://hexdocs.pm/floki/readme.html).\n\nThe input can be:\n\n* A string of HTML.\n* An [IO Data](https://hexdocs.pm/elixir/IO.html#module-io-data) of HTML.\n* A [Floki](https://hexdocs.pm/floki/readme.html) [html_node](https://hexdocs.pm/floki/Floki.html#t:html_node/0)\n  or [html_tree](https://hexdocs.pm/floki/Floki.html#t:html_tree/0) data structure. HtmlQuery uses Floki internally\n  and can accept its data structure as input, and some HtmlQuery functions return its data structure as output.\n* Anything that implements the `String.Chars` protocol. See [Implementing String.Chars](#implementing-string-chars)\n  below.\n\nWe created a related library called [XmlQuery](https://hexdocs.pm/xml_query/readme.html) which has the same API but\nis used for querying XML. You can read more about them in\n[Querying HTML and XML in Elixir with HtmlQuery and XmlQuery](https://eahanson.com/articles/html-query-xml-query).\n\nThis library is MIT licensed and is part of a growing number of Elixir open source libraries published at\n[github.com/synchronal](https://github.com/synchronal#elixir).\n\nThis library is tested against the most recent 3 versions of Elixir and Erlang.","ref":"readme.html"},{"type":"extras","title":"Installation - HtmlQuery","doc":"```elixir\ndef deps do\n  [\n    {:html_query, \"~> 4.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - HtmlQuery","doc":"Detailed docs are in the [HtmlQuery module docs](https://hexdocs.pm/html_query/HtmlQuery.html); a quick usage\noverview follows.\n\nWe typically alias `HtmlQuery` to `Hq`:\n\n```elixir\nalias HtmlQuery, as: Hq\n```\n\nThe rest of these examples use the following HTML:\n\n```elixir\nhtml = \"\"\"\n   Please update your profile \n   \n     Name    \n     Age    \n     Bio  Fido likes long walks and playing fetch.   \n   \n \n\"\"\"\n```","ref":"readme.html#usage"},{"type":"extras","title":"Querying - HtmlQuery","doc":"Query functions use CSS selector strings for finding nodes. The\n[MDN CSS Selectors guide](https://developer.mozilla.org/en-US/docs/Web/CSS/CSS_selectors/Selectors_and_combinators)\nis a helpful CSS reference.\n\n```elixir\nHq.find(html, \"form#profile label textarea\")\n```\n\nWe’ve found that reserving CSS classes and IDs for styling instead of using them for testing reduces the chance of\nstyling changes breaking tests, and so we often add attributes that start with `test-` into our HTML; a query for\n`test-role` would look like:\n\n```elixir\nHq.find(html, \"form[test-role=profile]\")\n```\n\nFor simple queries, [HtmlQuery.Css](https://hexdocs.pm/html_query/HtmlQuery.Css.html#selector/1) provides a shorthand\nusing keyword lists. For complicated queries, it’s usually clearer to use a CSS string.\n\n```elixir\nHq.find(html, test_role: \"profile\")\n```","ref":"readme.html#querying"},{"type":"extras","title":"Finding - HtmlQuery","doc":"`all/2` finds all elements matching the query, `find/2` returns the first element that matches the selector or `nil` if\nnone was found, and `find!/2` is like `find/2` but raises unless exactly one element is found.\n\n```elixir\nHq.all(html, \"input\") # returns a list of all the   elements\nHq.find(html, \"input[name=age]\") # returns the   with `name=age`\nHq.find!(html, \"input[name=foo]\") # raises because no such element exists\n```\n\nSee the [module docs](https://hexdocs.pm/html_query/HtmlQuery.html) for more details.","ref":"readme.html#finding"},{"type":"extras","title":"Extracting - HtmlQuery","doc":"`text/1` is the simplest extraction function:\n\n```elixir\nhtml |> Hq.find(:h1) |> Hq.text() # returns \"Please update your profile\"\n```\n\n`attr/2` returns the value of an attribute:\n\n```elixir\nhtml |> Hq.find(\"input[name=age]\") |> Hq.attr(:value) # returns \"10\"\n```\n\nTo extract data from multiple HTML nodes, we found that it is clearer to compose multiple functions rather than to\nhave a more complicated API:\n\n```elixir\nhtml |> Hq.all(:input) |> Enum.map(&Hq.text/1) # returns [\"Name\", \"Age\"]\nhtml |> Hq.all(\"input[type=text]\") |> Enum.map(&Hq.attr(&1, \"value\")) # returns [\"Fido\", \"10\"]\n```\n\nThere are also functions for extracting form fields as a map, meta tags as a list, and table contents as a list of\nlists or a list of maps. See the [module docs](https://hexdocs.pm/html_query/HtmlQuery.html) for more details.","ref":"readme.html#extracting"},{"type":"extras","title":"Parsing - HtmlQuery","doc":"`parse/1` and `parse_doc/1` delegate to Floki’s `parse_fragment/1` and `parse_document!/1` functions. These functions\nare rarely needed since all the HtmlQuery functions will parse HTML if needed. See the\n[module docs](https://hexdocs.pm/html_query/HtmlQuery.html) for more details.","ref":"readme.html#parsing"},{"type":"extras","title":"Utilities - HtmlQuery","doc":"`inspect_html/2` prints prettified HTML with a label, `normalize/1` parses and re-stringifies HTML which can be handy\nwhen trying to compare two strings of HTML, `pretty/1` formats HTML in a human-friendly format, and `reject/2` removes\nnodes that match the given selector. See the [module docs](https://hexdocs.pm/html_query/HtmlQuery.html) for more\ndetails.","ref":"readme.html#utilities"},{"type":"extras","title":"Implementing String.Chars - HtmlQuery","doc":"HtmlQuery functions that accept HTML will convert any module that implements `String.Chars`. For example, our\n[Pages](https://hexdocs.pm/pages/readme.html) testing library implements `String.Chars` for controller output like\nthis:\n\n```elixir\ndefimpl String.Chars do\n  def to_string(%Pages.Driver.Conn{conn: %Plug.Conn{status: 200} = conn}),\n    do: Phoenix.ConnTest.html_response(conn, 200)\nend\n```\n\nand implements `String.Chars` for LiveView output like this:\n\n```elixir\ndefimpl String.Chars, for: Pages.Driver.LiveView do\n  def to_string(%Pages.Driver.LiveView{rendered: rendered}) when not is_nil(rendered),\n    do: rendered\n\n  def to_string(%Pages.Driver.LiveView{live: live}) when not is_nil(live),\n    do: live |> Phoenix.LiveViewTest.render()\nend\n```","ref":"readme.html#implementing-string-chars"},{"type":"extras","title":"Development - HtmlQuery","doc":"```shell\nbrew bundle\n\nbin/dev/doctor\nbin/dev/update\nbin/dev/audit\nbin/dev/shipit\n```","ref":"readme.html#development"},{"type":"extras","title":"LICENSE","doc":"Copyright 2022 synchronal.dev\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the \"Software\"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}